import type { IoHelper } from '../../api-private';
/**
 * Run an async callback, swallowing any errors and logging them as debug messages.
 * Use this for code paths that must never break CLI execution.
 */
export declare function trapErrors<T>(ioHelper: IoHelper, message: string, cb: () => Promise<T>): Promise<T | undefined>;
