/**
 * Supported display modes for stack deployment activity
 */
export declare enum StackActivityProgress {
    /**
     * Displays a progress bar with only the events for the resource currently being deployed
     */
    BAR = "bar",
    /**
     * Displays complete history with all CloudFormation stack events
     */
    EVENTS = "events"
}
